# R12
A Python package providing a low-level interface for the ST Robotics R12
robotic arm.

## Install
Install using pip:
```
pip install r12
```

## Shell
The `r12-shell` executable is automatically installed with the package. It
provides a shell interface to the robot arm for testing.

## Manuals
See the ST Robotics manuals on the R12 arm and ROBOFORTH for more information.
* [Arm Manual](http://www.strobotics.com/manuals/R12%20manual.pdf)
* [ROBOFORTH Manual](http://www.strobotics.com/manuals/manual16.htm)
